@@ -12,7 +12,7 @@ import torch.multiprocessing as mp
 from fedbase.utils.model_utils import save_checkpoint, load_checkpoint
 import os
 
-os.chdir(os.path.dirname(os.path.abspath(__file__)))
+# os.chdir(os.path.dirname(os.path.abspath(__file__)))
 
 
 device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
